use warnings;
use strict;
require 't/LintTest.pl';

checkit( [
], [<DATA>] );

__DATA__
<HTML xmlns="Ding dang doodle" xml:lang="en" lang="en">
    <HEAD>
        <TITLE>Test stuff</TITLE>
    </HEAD>
    <BODY BGCOLOR="white">
        This test brought to you by M&ouml;tley Cr&uuml;e.
        <P>
        <PRE>
        Blah blah blah

        Now listen up
        She's razor sharp
        If she don't get her way
        She'll slice you apart
        Now she's cool cool black
        Moves like a cat
        If you don't get her game
        You might not make it back

        (Pre chorus)
        She's got the look's that kill
        That kill
        She's got the look's that kill
        That kill




        (Chorus)
        She's got the looks that kill

        Now she's bullet proof
        Keeps her motor clean
        And believe me you
        She's a number thirteen
        The church strikes midnight
        She's lookin' louder and louder
        She's gonna turn on your juice, boy
        So she turns on the power

        (Pre-chorus)
        She's got the looks that kill

        (Chorus)(Solo)(Verse)(Pre-chorus)(Chorus)
        </PRE>
    </BODY>
</HTML>
