use warnings;
use strict;
require 't/LintTest.pl';

checkit( [
], [<DATA>] );

__DATA__
<?php show_parallel_page() ?>

<html>
<head>
    <meta name="description" content="Follett Library Resources supplies books, eBooks, and audiovisual materials to more K-12 schools than any other wholesaler or publisher. We understand the needs of today's K-12 students and educators and continually strive to provide the best products and services available.">
    <meta http-equiv="content-type" content="text/html;charset=ISO-8859-1">
    <title>Welcome to Follett Library Resources</title>
</head>

<body bgcolor="#ffffff" link=white vlink=white leftmargin=1 topmargin=1 marginheight=1 marginwidth=1>
<table width="100%" border="0" cellspacing="0" cellpadding="0" bgcolor="white" height="122" HSPACE="1">
    <tr>
        <td align="left" valign="top" nowrap width="750" height="122"><img src="intro/graphics/hometop.jpg" alt="" height="122" width="750" usemap="#hometopb8e5aa3d" border="0"></td>
        <td align="right" valign="top" width="100%" height="122" background="intro/graphics/topright.jpg">&nbsp;</td>
    </tr>
</table>
		<table width="100%" border="0" cellspacing="0" cellpadding="0" align="left" bgcolor="white" height="100%">
    <tr>
		<td rowspan="2" align="left" valign="top" bgcolor="#006699" height="488" background="intro/graphics/leftbeigespacerbkgd.jpg">
			<div align="left">
				<img src="intro/graphics/leftcurve.jpg" alt="" height="71" width="213" align="top" border="0"><br>
				<table width="143" border="0" cellspacing="0" cellpadding="4" bgcolor="#006699">
							<tr>
								<td valign="top" nowrap width="13"></td>
								<td valign="top"><a href="intro/titletips.html"><img src="intro/graphics/titletips.gif" alt="" height="40" width="100" border="0"></a><br>
									<br>
								</td>
							</tr>
							<tr>
								<td valign="top" nowrap width="13"></td>
								<td valign="top"><font face="Arial,Helvetica,Geneva,Swiss,SunSans-Regular" size="3" color="white"><b><a href="/intro/sandcastle.html"><span Style="color: WHITE">SandCastle Early Literacy Program<br>
													<br>
												</span></a></b></font></td>
							</tr>
							<tr>
						<td valign="top" nowrap width="13"></td>
						<td valign="top"><font face="Arial,Helvetica,Geneva,Swiss,SunSans-Regular" size="3" color="white"><b><a href="/intro/keepyou.html"><span Style="color: WHITE">Library Products &amp; Services<br><br></span></a></b></font></td>
					</tr>
							<tr>
						<td width="13"></td>
						<td><font face="Arial,Helvetica,Geneva,Swiss,SunSans-Regular" size="3" color="white"><b><a href="/intro/classprodserv.html"><span Style="color: WHITE">Classroom Products &amp; Services<br><br></span></a></b></font></td>
					</tr>
							<tr>
								<td width="13"></td>
								<td><font size="3" color="#93ccff" face="Arial,Helvetica,Geneva,Swiss,SunSans-Regular"><b><a href="/intro/grantfunding.html"><span Style="color:white">Grant &amp; Funding Resources<br><br></span></a></b></font></td>
							</tr>
							<tr>
						<td width="13"></td>
						<td><font size="3" color="white" face="Arial,Helvetica,Geneva,Swiss,SunSans-Regular"><b><a href="/intro/curmap.html"><span Style="color: WHITE">Curriculum Mapping<br><br></span></a></b></font></td>
					</tr>
					<tr>
						<td valign="top" width="13"><nobr><font size="3" face="Arial,Helvetica,Geneva,Swiss,SunSans-Regular" color="white">&nbsp;</font></nobr></td>
						<td><font size="3" color="white" face="Arial,Helvetica,Geneva,Swiss,SunSans-Regular"><b><a href="/intro/newseve.html"><span Style="color:WHITE">Industry News &amp; Trends<br><br></span></a></b></font></td>
					</tr>
							<tr>
								<td valign="top" width="13"></td>
								<td><font size="3" color="white" face="Arial,Helvetica,Geneva,Swiss,SunSans-Regular"><b><a href="/intro/rli.html"><span Style="color: WHITE">Renaissance Learning Products<br><br></span></a></b></font></td>
							</tr>
						</table>
			</div>
		</td>
		<td align="right" valign="top" bgcolor="white" width="100%" height="280">
			<table width="100%" border="0" cellspacing="0" cellpadding="0" bgcolor="white" height="100%">
				<tr>
					<td width="100%" height="2"></td>
					<td align="right" valign="top" width="12" height="2"></td>
					<td rowspan="2" valign="top" bgcolor="white" width="142">
						<div align="right">
							<table width="130" border="0" cellspacing="0" cellpadding="0">
								<tr>
									<td colspan="3" width="142"><img src="intro/graphics/rightpaneltop.jpg" alt="" height="98" width="142" border="0"></td>
								</tr>
								<tr>
									<td align="left" valign="top" bgcolor="#cccc99" width="2" height="102%"><img src="/intro/graphics/beigepixels.jpg" alt="" height="2" width="2" border="0"></td>
									<td valign="top" bgcolor="#e7eef2" width="138" height="102%">
										<div align="center">
											<br>
											<table width="128" border="0" cellspacing="2" cellpadding="0">
														<tr>
															<td colspan="2"><a href="/login/"><img src="login/graphics/libtwbutt.gif" alt="" height="32" width="86" border="0"></a><br>
																<br>
															</td>
														</tr>
														<tr>
															<td colspan="2"><a href="/login/?side=C"><img src="login/graphics/curtwbutt.gif" alt="" height="32" width="86" border="0"></a><br>
																<br>
															</td>
														</tr>
														<tr>
															<td colspan="2"><a href="/login/?side=W"><img src="login/graphics/twisebutt.gif" alt="TitleWise login" border="0" height=43 width=82></a></td>
														</tr>
														<tr>
															<td colspan="2"><br>
																<font size="2" face="Arial,Helvetica,Geneva,Swiss,SunSans-Regular">Use TITLEWAVE to search for books and audiovisual materials, build and store lists, and order online.<br>
																	<br>Use TitleWise to identify the strengths &amp; weaknesses of school &amp; district collections. <br>
																	<br>
</font></td>
														</tr>
													</table>
										</div>
									</td>
									<td align="right" valign="top" bgcolor="#cccc99" width="2" height="102%"><img src="/intro/graphics/beigepixels.jpg" alt="" height="2" width="1" border="0"></td>
								</tr>
								<tr>
									<td colspan="3" align="left" valign="top" width="142"><img src="intro/graphics/rightpanelbottom.jpg" alt="" height="13" width="142" border="0"></td>
								</tr>
							</table>
						</div>
					</td>
				</tr>
				<tr>
					<td align="left" valign="top" bgcolor="white" width="100%" height="100%">
						<table width="100%" border="0" cellspacing="0" cellpadding="0">
							<tr>
								<td rowspan="2" align="left" valign="top" width="12" height="12"><img src="intro/graphics/beigecornertl.gif" alt="" height="12" width="12" border="0"></td>
								<td valign="top" bgcolor="#cccc99" width="50%" height="2"><img src="/intro/graphics/beigepixels.jpg" height="1" width="2" ALT=""></td>
								<td valign="top" bgcolor="#cccc99" width="10" height="2"><img src="/intro/graphics/beigepixels.jpg" height="1" width="2" ALT=""></td>
								<td valign="top" bgcolor="#cccc99" width="50%" height="2"><img src="/intro/graphics/beigepixels.jpg" height="1" width="2" ALT=""></td>
								<td rowspan="2" align="left" valign="top" width="13" height="12"><img src="intro/graphics/beigecornertr.gif" alt="" height="12" width="12" border="0"></td>
							</tr>
							<tr>
								<td width="50%" height="10"></td>
								<td width="10" height="10"></td>
								<td width="50%" height="10"></td>
							</tr>
							<tr>
										<td width="12" height="100%"></td>
										<td rowspan="3" valign="top">
											<div align="center">
												<p><a href="/login/"><object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.#version=5,0,30,0" height="350" width="200">
															<param name="movie" value="intro/graphics/av2students.swf">
															<param name="quality" value="best">
															<param name="play" value="true">
															<embed height="350" pluginspage="http://www.macromedia.com/shockwave/download/index.cgi?P1_Prod_Version=ShockwaveFlash" src="intro/graphics/av2students.swf" type="application/x-shockwave-flash" width="200" quality="best" play="true"> 
														</object><br>
														<br>
													</a><a href="/login/"><img src="intro/graphics/specialtestimonial2.jpg" alt="" height="227" width="180" border="0"></a></p>
											</div>
											<div align="left">
												<p><font size="2" face="Arial,Helvetica,Geneva,Swiss,SunSans-Regular">TITLEWAVE is the small school librarian&#146;s best friend. I use TITLEWAVE to search for books and to make and store book lists, and I especially count on the perfect MARC records.<br>
														<br>
														
								
								Calling the TITLEWAVE Customer Service Department is a real joy. Everyone there is cheerful, helpful, and ready to go when I need help. I love everything about TITLEWAVE.<br>
														<br>
														
								
								Sincerely,<br>
													</font><font size="2" color="#006699" face="Arial,Helvetica,Geneva,Swiss,SunSans-Regular"><b><i>Janie  Reavis  Cox<br>
																
										
										Stigler  High School<br>
																
										
										Library Media  Specialist <br>
																<br>
															</i></b></font><br>
												</p>
											</div>
										</td>
										<td width="10" height="100%"></td>
										<td rowspan="3" valign="top">
											<div align="left">
												<a href="/login/"><img src="intro/graphics/latestlists.jpg" alt="" border="0" height="109" width="200"></a><font size="2" face="Arial,Helvetica,Geneva,Swiss,SunSans-Regular"><br>&#149; New Mexico Land of <br>
													&nbsp;&nbsp;Enchantment 2005-06<br>
													&nbsp;&nbsp;Award Nominees<br>
													<br>&#149; Texas Lone Star <br>
													&nbsp;&nbsp;Reading List 2005-06<br>
													&nbsp;&nbsp;<a href="intro/pdfs/lonestarchart0506.pdf"><span Style="color:006699">Click here for a</span></a><br>
													
													
													
														&nbsp;&nbsp;<a href="intro/pdfs/lonestarchart0506.pdf"><span Style="color:006699">Student Reading Chart</span></a><br>
													<br>
													
													
													&#149; Texas Bluebonnet<br>
													
													
													
													&nbsp;&nbsp;Award 2005-06<br>
													
													
													
													&nbsp;&nbsp;<a href="intro/pdfs/BluebonnetChart0506.pdf"><span Style="color:006699">Click here for a</span></a><br>
													
													
													
														&nbsp;&nbsp;<a href="intro/pdfs/BluebonnetChart0506.pdf"><span Style="color:006699">Student Reading Chart</span></a><br>
													<br>
													
													
													
													&#149; Iowa Teen Award<br>
													
													
													
													&nbsp;&nbsp;Nominees 2005-06<br>
													
													
													
													&nbsp;&nbsp;<br>
													
													
													
													&#149; Wisconsin Battle<br>
													
													
													
													&nbsp;&nbsp;of the Books 2004-05<br>
												</font><img src="intro/graphics/latestlistline.jpg" alt="" border="0" height="31" width="199"><br>
												<br>
												<a href="/login/"><img src="intro/graphics/thomsongale.gif" alt="" height="169" width="200" border="0"></a><br>
												<a href="/intro/sandcastle.html"><img src="intro/graphics/SC.gif" alt="" border="0" height=353 width=200></a><br>
											</div>
										</td>
										<td align="right" valign="top" width="8" height="100%"></td>
									</tr>
							<tr>
								<td width="12" height="100%"></td>
								<td width="10" height="100%"></td>
								<td align="right" valign="top" width="8" height="100%"></td>
							</tr>
							<tr>
								<td width="12" height="100%"></td>
								<td width="10" height="100%">&nbsp;&nbsp;</td>
								<td align="right" valign="top" width="8" height="100%"></td>
							</tr>
							<tr>
								<td rowspan="2" align="left" valign="bottom" width="12" height="12"><img src="intro/graphics/beigecornerbl.gif" alt="" height="12" width="12" border="0"></td>
								<td width="50%" height="10"></td>
								<td width="10" height="10"></td>
								<td width="50%" height="10"></td>
								<td rowspan="2" align="left" valign="bottom" width="13" height="12"><img src="intro/graphics/beigecornerbr.gif" alt="" height="12" width="12" border="0"></td>
							</tr>
							<tr>
								<td valign="bottom" bgcolor="#cccc99" width="50%" height="2"><img src="/intro/graphics/beigepixels.jpg" alt="" height="1" width="2" align="bottom" border="0"></td>
								<td valign="bottom" bgcolor="#cccc99" width="10" height="2"><img src="/intro/graphics/beigepixels.jpg" alt="" height="1" width="2" align="bottom" border="0"></td>
								<td valign="bottom" bgcolor="#cccc99" width="50%" height="2"><img src="/intro/graphics/beigepixels.jpg" alt="" height="1" width="2" align="bottom" border="0"></td>
							</tr>
						</table>
					</td>
					<td bgcolor="white" width="12" height="100%">&nbsp;&nbsp;</td>
				</tr>
			</table>
		</td>
	</tr>
	<tr>
		<td align="left" valign="top" bgcolor="white" width="100%" height="20">
			<table width="100%" border="0" cellspacing="0" cellpadding="0" height="100%">
				<tr>
					<td valign="bottom" width="100%" height="20">
						<table width="100%" border="0" cellspacing="0" cellpadding="0">
							<tr>
								<td rowspan="2" align="left" valign="top" width="12" height="12"><img src="intro/graphics/beigecornertl.gif" alt="" height="12" width="12" border="0"></td>
								<td valign="top" bgcolor="#cccc99" width="50%" height="2"><img src="/intro/graphics/beigepixels.jpg" height="1" width="2" alt=""></td>
								<td valign="top" bgcolor="#cccc99" width="10" height="2"><img src="/intro/graphics/beigepixels.jpg" height="1" width="2" alt=""></td>
								<td valign="top" bgcolor="#cccc99" width="50%" height="2"><img src="/intro/graphics/beigepixels.jpg" height="1" width="2" alt=""></td>
								<td rowspan="2" align="left" valign="top" width="13" height="12"><img src="intro/graphics/beigecornertr.gif" alt="" height="12" width="12" border="0"></td>
							</tr>
							<tr>
                                                            <td colspan=3 height=10></td>
							</tr>
							<tr>
								<td width="12"></td>
								<td colspan="3" valign="top">
									<div align="center">
										<font size="1" face="Arial,Helvetica,Geneva,Swiss,SunSans-Regular">Copyright &copy; 2004 <a href="mailto:titlewave@flr.follett.com"><span Style="color:006699">Follett Library Resources</span></a>&nbsp; 1340 Ridgeview Drive&nbsp; McHenry, Illinois 60050<br>
											&nbsp;Phone: 888.511.5114 or 815.759.1700&nbsp; Fax: 800.852.5458 or 815.759.9831<br>
											&nbsp;Customer Service: <a href="mailto:customerservice@flr.follett.com"><span Style="color:006699">customerservice@flr.follett.com</span></a> or 800.435.6170<br>
										</font></div>
								</td>
								<td align="right" width="13"></td>
							</tr>
						</table>
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>
</body>
</html>
